@@ -125,9 +125,9 @@ static apr_status_t redwax_keychain_complete_keychain_in(redwax_tool_t *r,
 
             if (err == errSecSuccess) {
 
-            	name = apr_pstrndup(r->pool, buffer, len);
+                name = apr_pstrndup(r->pool, buffer, len);
 
-            	apr_hash_set(paths, name, APR_HASH_KEY_STRING, name);
+                apr_hash_set(paths, name, APR_HASH_KEY_STRING, name);
 
             }
 
@@ -242,6 +242,8 @@ static apr_status_t redwax_keychain_process_certificates(redwax_tool_t *r)
                 sizeof(redwax_certificate_t));
         cert->pool = p;
 
+        cert->per_module = redwax_create_module_config(cert->pool);
+
         cert->common.type = REDWAX_CERTIFICATE_X509;
 
         CFDataRef der = SecCertificateCopyData(cref);
@@ -351,6 +353,8 @@ static apr_status_t redwax_keychain_process_trusted(redwax_tool_t *r)
                 sizeof(redwax_certificate_t));
         cert->pool = p;
 
+        cert->per_module = redwax_create_module_config(cert->pool);
+
         cert->common.type = REDWAX_CERTIFICATE_X509;
 
         CFDataRef der = SecCertificateCopyData(cref);
@@ -578,7 +582,6 @@ static apr_status_t redwax_keychain_process_keychain_in(redwax_tool_t *r,
 
     keychain_config_t *config;
 
-    r->per_module = redwax_create_module_config(r->pool);
     config = apr_pcalloc(r->pool, sizeof(keychain_config_t));
     redwax_set_module_config(r->per_module, &keychain_module, config);
 
@@ -639,6 +642,8 @@ found:
         return status;
     }
 
+// fixme - trusted needs own config option
+
     if (APR_SUCCESS != (status = redwax_keychain_process_trusted(r))) {
         return status;
     }
@@ -659,7 +664,7 @@ static apr_status_t redwax_keychain_search_key(redwax_tool_t *r,
 
     config = redwax_get_module_config(r->per_module, &keychain_module);
 
-    if (cert->der && config->in) {
+    if (cert->der && config && config->in) {
 
         OSStatus err;
 
