@@ -32,6 +32,7 @@
 
 #include "config.h"
 #include "redwax-tool.h"
+#include "redwax_util.h"
 
 #if HAVE_NSS_INITIALIZE
 
@@ -56,6 +57,8 @@ typedef struct redwax_nss_secret_t {
     int verify;
 } redwax_nss_secret_t;
 
+module nss_module;
+
 static apr_status_t cleanup_nss(void *dummy)
 {
     if (dummy) {
@@ -788,4 +791,16 @@ void redwax_add_default_nss_hooks()
     rt_hook_complete_nss_token_out(redwax_nss_complete_nss_token_out, NULL, NULL, APR_HOOK_MIDDLE);
 }
 
+#else
+
+void redwax_add_default_nss_hooks()
+{
+}
+
 #endif
+
+REDWAX_DECLARE_MODULE(nss) =
+{
+    STANDARD_MODULE_STUFF,
+    redwax_add_default_nss_hooks                   /* register hooks */
+};
